==> feature-0.20-sources.jar: boofcv/alg/tracker/klt/KltFeatureSelector.java <==
/*
 * Copyright (c) 2011-2013, Peter Abeles. All Rights Reserved.
 *
 * This file is part of BoofCV (http://boofcv.org).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package boofcv.alg.tracker.klt;

import boofcv.struct.image.ImageSingleBand;

import java.util.List;

/**
 * Automatically selects KLT features and creates descriptions of them.  There are many different ways to do this
 * for different applications.
 *
 * @author Peter Abeles
 */
public interface KltFeatureSelector<InputImage extends ImageSingleBand, DerivativeImage extends ImageSingleBand> {

	/**
	 * Sets the current image and image derivatives
	 *
	 * @param image  Original image.
	 * @param derivX Image derivative along the x-axis.
	 * @param derivY Image derivative along the y-axis.
	 */
	public void setInputs(InputImage image, DerivativeImage derivX, DerivativeImage derivY);

	/**
	 * Selects new features using provided data structures.
	 *
	 * @param active List of currently active features which should not be returned again.
	 * @param availableData List of feature data that can be used to create a new features.
	 */
	public void compute( List<KltFeature> active , List<KltFeature> availableData );


}

==> feature-0.26-sources.jar: boofcv/alg/tracker/klt/KltFeatureSelector.java <==
/*
 * Copyright (c) 2011-2016, Peter Abeles. All Rights Reserved.
 *
 * This file is part of BoofCV (http://boofcv.org).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package boofcv.alg.tracker.klt;

import boofcv.struct.image.ImageGray;

import java.util.List;

/**
 * Automatically selects KLT features and creates descriptions of them.  There are many different ways to do this
 * for different applications.
 *
 * @author Peter Abeles
 */
public interface KltFeatureSelector<InputImage extends ImageGray, DerivativeImage extends ImageGray> {

	/**
	 * Sets the current image and image derivatives
	 *
	 * @param image  Original image.
	 * @param derivX Image derivative along the x-axis.
	 * @param derivY Image derivative along the y-axis.
	 */
	public void setInputs(InputImage image, DerivativeImage derivX, DerivativeImage derivY);

	/**
	 * Selects new features using provided data structures.
	 *
	 * @param active List of currently active features which should not be returned again.
	 * @param availableData List of feature data that can be used to create a new features.
	 */
	public void compute( List<KltFeature> active , List<KltFeature> availableData );


}
